@@ -4,6 +4,7 @@ from logging import Logger, getLogger
 from typing import Any, AsyncIterator, Callable, Iterable, List, Optional, cast
 
 from asyncpg import Connection, connect
+from asyncpg.transaction import Transaction
 
 import apgw.builder as builder
 from apgw.constraint import Constraints
@@ -76,11 +77,11 @@ class DBBase:
         return self
 
     @asynccontextmanager
-    async def transaction(self) -> AsyncIterator["DBBase"]:
+    async def transaction(self) -> AsyncIterator[Transaction]:
         """Run a command in a database transaction."""
         await self.auto_open()
-        async with self.conn.transaction():
-            yield self
+        async with self.conn.transaction() as trans:
+            yield trans
 
     async def __aenter__(self) -> "DBBase":
         """Asynchronous context manager entry point."""
