@@ -1,5 +1,5 @@
-'''Shared types.'''
-from typing import (Any, List, Mapping, Optional, Tuple, Union)
+"""Shared types."""
+from typing import Any, List, Mapping, Optional, Tuple, Union
 
 ConnectionArgs = Union[Mapping[str, str], str]
 
